PyRlin is a simple library that lets you generate Perlin Noise. It is very useful for things like 2D terrain generation. It generates noise with levels from 0-100 by default.

# Installation
pip install PyRlin

# Usage
PyRlin.perleanate(4, 5)
PyRlin.perleanate_no_edges(4, 5)
PyRlin.multiple_perleanate(4, 5, 6)
PyRlin.rounded_no_edges_perleanate(4, 5)
PyRlin.split_noise(noise, 50)
PyRlin.make_map(noise)